@@ -2,7 +2,6 @@ mae = function(forecast, true)
 {
     if (length(forecast) != length(true))
         stop("MAE: the lengths of input vectors must be the same.")
-    err = mean(abs(forecast - true))
+    err = mean(abs(true - forecast))
     return(round(err, 6))
 }
-
