@@ -2,8 +2,8 @@ relmae = function(forecast, forecastbench, true)
 {
   if (length(forecast) != length(true))
       stop("RelMAE: the lengths of input vectors must be the same.")
-  ferror = ftsa:::mae(forecast, true)
-  ferrorbench = ftsa:::mae(forecastbench, true)
+  ferror = mean(abs(true - forecast))
+  ferrorbench = mean(abs(true - forecastbench))  
   relativerror = ferror / ferrorbench
   return(round(relativerror, 6))
 }
